==> ihopesproperties-1.0.2.tar.gz: ihopesproperties-1.0.2/src/my_asana/utils.py <==
from asana import StoriesApi

from my_asana.authenticate import get_tasks_api, get_stories_api
from my_asana.consts import LEADS_PROJECT_ID, LEADS_PROPERTIES_SECTION, PROPERTY_TASK_TEMPLATE_ID
from property import Property


def is_task_exists(property: Property) -> bool:
    tasks_api = get_tasks_api()
    tasks = tasks_api.get_tasks_for_project(LEADS_PROJECT_ID, opts={})
    property_full_address = property.address.get_full_address()
    for task in tasks:
        if task['name'] == property_full_address:
            print(f"Task already exists for: {property_full_address}")
            return True
    return False


def add_task_to_section(task_id: str, section_id: str, project_id: str = LEADS_PROJECT_ID,
                        insert_at_the_top: bool = False):
    """
    Add a task to a specific section in a project
    :param task_id: task ID to add
    :param section_id: section ID to add the task to
    :param project_id: project ID to add the task to
    :param insert_at_the_top: boolean to insert the task at the top of the section
    :return:
    """
    tasks_api = get_tasks_api()

    data = {
        "data": {
            "project": project_id,
        }
    }
    if insert_at_the_top:
        data['data']['insert_after'] = PROPERTY_TASK_TEMPLATE_ID
    else:
        data['data']['section'] = section_id

    # Add the task to the project and section using the 'add_project_for_task' method
    tasks_api.add_project_for_task(task_gid=task_id, body=data)
    print(f'Added task {task_id} to section {section_id}')


def update_task(task_id: str, data: dict):
    """
    Update a task using the Asana API
    :param task_id: task ID to update
    :param data: data to update the task with
    :return:
    """
    tasks_api = get_tasks_api()
    tasks_api.update_task(
        task_gid=task_id,
        body={"data": data},
        opts={}
    )
    print(f'Updated task {task_id}')

==> ihopesproperties-1.1.0.tar.gz: ihopesproperties-1.1.0/src/my_asana/utils.py <==
from asana import StoriesApi

from common.utils.address_maniplator import update_address_with_pittsburgh_ciy
from my_asana.authenticate import get_tasks_api, get_stories_api
from my_asana.consts import LEADS_PROJECT_ID, LEADS_PROPERTIES_SECTION, PROPERTY_TASK_TEMPLATE_ID
from property import Property, PropertyAddress


def is_task_exists(property_address: str) -> bool:
    tasks_api = get_tasks_api()
    tasks = tasks_api.get_tasks_for_project(LEADS_PROJECT_ID, opts={})
    updated_property_address: str = update_address_with_pittsburgh_ciy(
        address=PropertyAddress.from_full_address(property_address)).get_full_address()
    for task in tasks:
        if task['name'] == property_address or task['name'] == updated_property_address:
            print(f"Task already exists for: {property_address}")
            return True
    return False


def add_task_to_section(task_id: str, section_id: str, project_id: str = LEADS_PROJECT_ID,
                        insert_at_the_top: bool = False):
    """
    Add a task to a specific section in a project
    :param task_id: task ID to add
    :param section_id: section ID to add the task to
    :param project_id: project ID to add the task to
    :param insert_at_the_top: boolean to insert the task at the top of the section
    :return:
    """
    tasks_api = get_tasks_api()

    data = {
        "data": {
            "project": project_id,
        }
    }
    if insert_at_the_top:
        data['data']['insert_after'] = PROPERTY_TASK_TEMPLATE_ID
    else:
        data['data']['section'] = section_id

    # Add the task to the project and section using the 'add_project_for_task' method
    tasks_api.add_project_for_task(task_gid=task_id, body=data)
    print(f'Added task {task_id} to section {section_id}')


def update_task(task_id: str, data: dict):
    """
    Update a task using the Asana API
    :param task_id: task ID to update
    :param data: data to update the task with
    :return:
    """
    tasks_api = get_tasks_api()
    tasks_api.update_task(
        task_gid=task_id,
        body={"data": data},
        opts={}
    )
    print(f'Updated task {task_id}')
